import ray
from ray.job_submission import JobSubmissionClient
import urllib3
import time

# Suppress the warning about unverified HTTPS requests since 
# we are using self signed certificates for testing 
urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

# Ray client
client = JobSubmissionClient(
    "<https URL for Ray Endpoint>", 
    headers={"Authorization": "Basic <Base64 Encoded Credentials>"}, 
    verify=False  # Disable SSL verification
)

# Submit the job to the remote Ray cluster
job_id = client.submit_job(
    entrypoint="python simple.py",  # The script to be executed remotely
    runtime_env={
        "working_dir": "./",  # The working directory containing the script
        "pip": []  # No additional dependencies for this simple test
    }
)

print(f"Submitted job with ID: {job_id}")

# Check the status of the job
status = client.get_job_status(job_id)
print(f"Job status: {status}")
while status != "SUCCEEDED":
    print(f"Job status: {status}")
    time.sleep(5)  # Wait 5 seconds before checking again
    status = client.get_job_status(job_id)

print("Job has succeeded!")

# Retrieve the logs or output of the job
logs = client.get_job_logs(job_id)
print(f"Job logs: {logs}")